@@ -29,7 +29,7 @@
 
       CALL SGOPN(IWS)
 
-      CALL SGLSET('LSOFTF',.TRUE.)           ! <-- եȥեλ
+      CALL SGLSET('LSOFTF',.TRUE.)           ! <-- ソフトフィルの指定
       CALL SGFRM
 
       CALL SGSWND(-1., 1., -1., 1.)
@@ -38,20 +38,20 @@
       CALL SGSTRF
 
       CALL SGPLU(3, UPX3, UPY3)
-      CALL SGTNU(3, UPX3, UPY3)              ! <-- ֤ ()
+      CALL SGTNU(3, UPX3, UPY3)              ! <-- 網かけ (左下)
 
       CALL SGSVPT(0., 0.5, 0.5, 1.)
       CALL SGSTRF
       CALL SGSTNP(101)
-      CALL SGTNU(6, UPX6, UPY6)              ! <--  ()
+      CALL SGTNU(6, UPX6, UPY6)              ! <-- 横線 (左上)
 
       CALL SGSVPT(0.5, 1., 0., 0.5)
       CALL SGSTRF
-      CALL SGTNZU(6, UPX6, UPY6, 201)        ! <--  ()
+      CALL SGTNZU(6, UPX6, UPY6, 201)        ! <-- 斜線 (右下)
 
       CALL SGSVPT(0.5, 1., 0.5, 1.)
       CALL SGSTRF
-      CALL SGTNZU(61, UPXS, UPYS, 601)       ! <--  ()
+      CALL SGTNZU(61, UPXS, UPYS, 601)       ! <-- 横線 (右上)
 
       CALL SGCLS
 
