@@ -5,6 +5,8 @@
       LOGICAL   LFCATR
       INTEGER   ITPATX
 
+      CALL SGIGET('IFCIDX',IFCIDX)
+
       CALL SWQFCC(LFCATR)
       IF(.NOT.LFCATR) THEN
         CALL MSGDMP('M','SGTNXR','FULL COLOR MODE IS NOT SUPPORTED.')
@@ -25,7 +27,7 @@
       CALL SWSTCL(ICOLOR)
       CALL SWSLCL(ICOLOR)
 
-      ITPATX=999*1000+MOD(ITPAT,1000)
+      ITPATX=IFCIDX*1000+MOD(ITPAT,1000)
       CALL SZTNOP(ITPATX)
       CALL SZTNZR(N,RPX,RPY)
       CALL SZTNCL
