@@ -114,7 +114,13 @@ static cairo_surface_t *csi;
 static char imgfmt[8];
 static DCL_REAL imgcmp;
 
+#if GTKVERSION==2
 static GdkColor cx[MAXCLI];
+#elif GTKVERSION==3
+static GdkColor cx[MAXCLI];
+#else
+static GdkRGBA cx[MAXCLI];
+#endif
 
 static int ifunc, next;
 static int dumpz = FALSE;
@@ -380,7 +386,13 @@ gboolean zg_draw_event(GtkWidget *widget, cairo_t *cr)
 }
 #endif
 
+#if GTKVERSION==2
 gint zg_key_press_event(GtkWidget *widget, GdkEventKey *event)
+#elif GTKVERSION==3
+gint zg_key_press_event(GtkWidget *widget, GdkEventKey *event)
+#else
+gint zg_key_press_event(GtkWidget *widget, GdkEvent *event)
+#endif
 {
   switch (ifunc){
   case DOPN:
@@ -388,7 +400,14 @@ gint zg_key_press_event(GtkWidget *widget, GdkEventKey *event)
     break;
 
   case DCLS:
+#if GTKVERSION==2
     switch (event->keyval) {
+#elif GTKVERSION==3
+    switch (event->keyval) {
+#else
+    switch (gdk_key_event_get_keyval(event)){
+#endif
+
 #if GTKVERSION==2
     case GDK_space:
     case GDK_Return:
@@ -404,7 +423,14 @@ gint zg_key_press_event(GtkWidget *widget, GdkEventKey *event)
     break;
 
   case PCLS:
+#if GTKVERSION==2
     switch (event->keyval) {
+#elif GTKVERSION==3
+    switch (event->keyval) {
+#else
+    switch (gdk_key_event_get_keyval(event)){
+#endif
+      
 #if GTKVERSION==2
     case GDK_w:
 #else
@@ -455,7 +481,13 @@ gint zg_key_press_event(GtkWidget *widget, GdkEventKey *event)
   return TRUE;
 }
 
+#if GTKVERSION==2
 gint zg_button_press_event(GtkWidget *widget, GdkEventButton *event)
+#elif GTKVERSION==3
+gint zg_button_press_event(GtkWidget *widget, GdkEventButton *event)
+#else
+gint zg_button_press_event(GtkWidget *widget, GdkEvent *event)
+#endif
 {
   switch (ifunc){
   case DOPN:
@@ -470,7 +502,13 @@ gint zg_button_press_event(GtkWidget *widget, GdkEventButton *event)
   return TRUE;
 }
 
+#if GTKVERSION==2
 gint zg_destroy_event(GtkWidget *widget, GdkEventButton *event)
+#elif GTKVERSION==3
+gint zg_destroy_event(GtkWidget *widget, GdkEventButton *event)
+#else
+gint zg_destroy_event(GtkWidget *widget, GdkEvent *event)
+#endif
 {
 #if GTKVERSION==2
       gtk_exit(0);
@@ -488,16 +526,26 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
 {
   GtkWidget * drw;
   GtkWidget *vbox;
-
+#if GTKVERSION==2
   gtk_init(0,NULL);
-
+#elif GTKVERSION==3
+  gtk_init(0,NULL);
+#else
+  gtk_init();
+#endif
+  
 #if GTKVERSION==2
   drw=gtk_drawing_area_new();
+  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+#elif GTKVERSION==3
+  drw = (GtkWidget*)gtk_drawing_area_new();
+  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 #else
   drw = (GtkWidget*)gtk_drawing_area_new();
+  window = gtk_window_new();
 #endif
 
-  window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
+
 
 #if GTKVERSION==2
   gtk_drawing_area_size(GTK_DRAWING_AREA (drw), wsxwd, wsywd);
@@ -521,15 +569,19 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
       gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK|GDK_KEY_PRESS_MASK);
       gtk_signal_connect(GTK_OBJECT (window), "key_press_event",
 			 (GtkSignalFunc) zg_key_press_event, NULL);
-
-#else
+#elif GTKVERSION==3
       gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK|GDK_KEY_PRESS_MASK);
       g_signal_connect(G_OBJECT(window), "button_press_event",
                           G_CALLBACK(zg_button_press_event), NULL);
+#else
+      gtk_widget_set_events(window, GDK_BUTTON_PRESS|GDK_KEY_PRESS);
+      g_signal_connect(G_OBJECT(window), "button_press_event",
+                          G_CALLBACK(zg_button_press_event), NULL);
 #endif
     }
-      gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK|GDK_KEY_PRESS_MASK);
+
 #if GTKVERSION==2
+    gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK|GDK_KEY_PRESS_MASK);
     gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK);
     gtk_signal_connect(GTK_OBJECT (window), "button_press_event",
   		       (GtkSignalFunc) zg_button_press_event, NULL);
@@ -538,9 +590,29 @@ static GtkWidget *ZGGDRW(DCL_INT *width, DCL_INT *height)
   		       (GtkSignalFunc) zg_expose_event, NULL);
     gtk_signal_connect(GTK_OBJECT (window), "destroy",
   		       (GtkSignalFunc) zg_destroy_event, NULL);
+    /*#elif GTKVERSION==3
+    //      gtk_widget_set_events(drw, GDK_EXPOSURE_MASK);
+    gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK);
+    g_signal_connect(G_OBJECT(window), "key_press_event",
+                      G_CALLBACK(zg_key_press_event), NULL);
+    g_signal_connect (G_OBJECT(drw), "draw",
+                      G_CALLBACK(zg_draw_event), NULL);
+    g_signal_connect(G_OBJECT (window), "destroy",
+    G_CALLBACK(zg_destroy_event), NULL);*/
+#elif GTKVERSION==3
+//      gtk_widget_set_events(drw, GDK_EXPOSURE_MASK);
+    gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK|GDK_KEY_PRESS_MASK);
+    gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK);
+    g_signal_connect(G_OBJECT(window), "key_press_event",
+                      G_CALLBACK(zg_key_press_event), NULL);
+    g_signal_connect (G_OBJECT(drw), "draw",
+                      G_CALLBACK(zg_draw_event), NULL);
+    g_signal_connect(G_OBJECT (window), "destroy",
+  	          	      G_CALLBACK(zg_destroy_event), NULL);
 #else
 //      gtk_widget_set_events(drw, GDK_EXPOSURE_MASK);
-    gtk_widget_set_events(window, GDK_BUTTON_PRESS_MASK);
+    gtk_widget_set_events(window, GDK_BUTTON_PRESS|GDK_KEY_PRESS);
+    gtk_widget_set_events(window, GDK_BUTTON_PRESS);
     g_signal_connect(G_OBJECT(window), "key_press_event",
                       G_CALLBACK(zg_key_press_event), NULL);
     g_signal_connect (G_OBJECT(drw), "draw",
@@ -674,7 +746,7 @@ void ZGDOPN(DCL_INT *dev_type,
 
   FILE *stream;
 
-  GdkVisual *vis;
+  //  GdkVisual *vis;
 
   GdkRectangle update_rect;
   GdkEvent *ev;
@@ -2558,7 +2630,13 @@ void zgslcl_(DCL_INT *icolor)
 void ZGSLCL(DCL_INT *icolor)
 #endif
 {
+#if GTKVERSION==2
   GdkColor loccx;
+#elif GTKVERSION==3
+  GdkColor loccx;
+#else
+  GdkRGBA loccx;
+#endif
 
 //  double rt1,gt1,bt1;
 
@@ -2582,7 +2660,13 @@ void ZGSTCL(DCL_INT *icolor)
   /*This Function is not used in uipk samples
      So, it is not tested.*/
   /* set tone color in 24 bit RGB */
+#if GTKVERSION==2
   GdkColor  loccx;
+#elif GTKVERSION==3
+  GdkColor  loccx;
+#else
+  GdkRGBA  loccx;
+#endif
   double rt1,gt1,bt1;
 
   if (ltfrst) {
@@ -2606,7 +2690,14 @@ void zgiclr_(DCL_INT *image,DCL_INT *nlen)
 void ZGICLR(DCL_INT *image,DCL_INT *nlen)
 #endif
 {
+#if GTKVERSION==2
   GdkColor  loccx;
+#elif GTKVERSION==3
+  GdkColor  loccx;
+#else
+  GdkRGBA  loccx;
+#endif
+
   int i,ofs;
   int e=1;
   double rt1,gt1,bt1;
