@@ -1,10 +1,14 @@
+#include "../../../config.h"
 /*
  *	ishift
  */
-long ishift_(i, nshift)
-    long *i, *nshift;
+#ifndef WINDOWS
+DCL_INT ishift_(DCL_INT *i, DCL_INT *nshift)
+#else
+DCL_INT ISHIFT(DCL_INT *i, DCL_INT *nshift)
+#endif
 {
-    long jshift, nbits;
+    DCL_INT jshift, nbits;
 
     if (*nshift < 0) {
 	nbits = (*nshift < -32 ? 32 : -*nshift);
