@@ -4,12 +4,12 @@
 module chg_interface
   interface
 
-    subroutine cupper(ch)                         !ʸʸ롥
-      character(len=*), intent(inout) :: ch       !ʸ
+    subroutine cupper(ch)                         !文字列を大文字化化する．
+      character(len=*), intent(inout) :: ch       !処理する文字列
     end subroutine
       
-    subroutine clower(ch)                         !ʸʸ롥
-      character(len=*), intent(inout) :: ch       !ʸ
+    subroutine clower(ch)                         !文字列を小文字化する．
+      character(len=*), intent(inout) :: ch       !処理する文字列
     end subroutine
 
   end interface
