@@ -5,7 +5,7 @@ module rfblib
   use dcl_common
   contains
 
-    function DclGetPRD(x,y)                        !Ѥ
+    function DclGetPRD(x,y)                        !内積を求める
       real, intent(in), dimension(:) :: x
       real, intent(in), dimension(:) :: y
       real                           :: DclGetPRD
@@ -15,7 +15,7 @@ module rfblib
       call prccls('DclGetPRD')
     end function
       
-    function DclGetCOV(x,y)                        !ʬ
+    function DclGetCOV(x,y)                        !共分散を求める
       real, intent(in), dimension(:) :: x
       real, intent(in), dimension(:) :: y
       real                           :: DclGetCOV
@@ -25,7 +25,7 @@ module rfblib
       call prccls('DclGetCOV')
     end function
       
-    function DclGetCOR(x,y)                        !ط
+    function DclGetCOR(x,y)                        !相関係数を求める
       real, intent(in), dimension(:) :: x
       real, intent(in), dimension(:) :: y
       real                           :: DclGetCOR
