@@ -22,15 +22,15 @@ module sgpack
 
   contains
 !---------------------------------------------------------
-    subroutine DclPrintDeviceList() !ơ̾Υꥹ
+    subroutine DclPrintDeviceList() !ワークステーション名のリスト
       call prcopn('DclPrintDeviceList')
       call sgpwsn()
       call prccls('DclPrintDeviceList')
     end subroutine
 !------------------------------------------------------------------------
-!Ѵ
+!正規化変換
 !---------------------------------
-    subroutine DclTransShortToLong(short,long) !άΤ̾Τ롥
+    subroutine DclTransShortToLong(short,long) !略称から名称を求める．
       character(len=*), intent(in)  :: short 
       character(len=*), intent(out) :: long
 
@@ -39,7 +39,7 @@ module sgpack
       call prccls('DclTransShortToLong')
     end subroutine
 !---------------------------------
-    subroutine DclTransShortToNum(short,num) !άΤѴؿֹ롥
+    subroutine DclTransShortToNum(short,num) !略称から変換関数番号を求める．
       character(len=*), intent(in)  :: short 
       integer,          intent(out) :: num
 
@@ -48,7 +48,7 @@ module sgpack
       call prccls('DclTransShortToNum')
     end subroutine
 !---------------------------------
-    subroutine DclTransLongToShort(long,short) !̾ΤάΤ롥
+    subroutine DclTransLongToShort(long,short) !名称から略称を求める．
       character(len=*), intent(in)  :: long
       character(len=*), intent(out) :: short 
 
@@ -57,7 +57,7 @@ module sgpack
       call prccls('DclTransLongToShort')
     end subroutine
 !---------------------------------
-    subroutine DclTransLongToNum(long,num) !̾ΤѴؿֹ롥
+    subroutine DclTransLongToNum(long,num) !名称から変換関数番号を求める．
       character(len=*), intent(in)  :: long
       integer,          intent(out) :: num
 
@@ -66,7 +66,7 @@ module sgpack
       call prccls('DclTransLongToNum')
     end subroutine
 !---------------------------------
-    subroutine DclTransNumToShort(num,short) !Ѵؿֹ椫άΤ롥
+    subroutine DclTransNumToShort(num,short) !変換関数番号から略称を求める．
       integer,          intent(in)  :: num
       character(len=*), intent(out) :: short
 
@@ -75,7 +75,7 @@ module sgpack
       call prccls('DclTransNumToShort')
     end subroutine
 !---------------------------------
-    subroutine DclTransNumToLong(num,long) !Ѵؿֹ椫̾Τ롥
+    subroutine DclTransNumToLong(num,long) !変換関数番号から名称を求める．
       integer,          intent(in) :: num
       character(len=*), intent(out) :: long
 
@@ -85,7 +85,7 @@ module sgpack
     end subroutine
 !---------------------------------
     subroutine DclGetViewPort(xmin, xmax, ymin, ymax) 
-      real, intent(out), optional :: xmin, xmax, ymin, ymax !ӥ塼ݡ
+      real, intent(out), optional :: xmin, xmax, ymin, ymax !ビューポート
 
       call prcopn('DclGetViewPort')
       call sgqvpt(xmin0, xmax0, ymin0, ymax0) 
@@ -97,7 +97,7 @@ module sgpack
     end subroutine
 !---------------------------------
     subroutine DclGetWindow(xmin, xmax, ymin, ymax) 
-      real, intent(out), optional :: xmin, xmax, ymin, ymax !ɥ
+      real, intent(out), optional :: xmin, xmax, ymin, ymax !ウインドウ
 
       call prcopn('DclGetWindow')
       call sgqwnd(xmin0, xmax0, ymin0, ymax0) 
@@ -132,16 +132,16 @@ module sgpack
     end subroutine
 !---------------------------------
     function DclGetTransNumber() 
-      integer :: DclGetTransNumber     !Ѵؿֹ
+      integer :: DclGetTransNumber     !変換関数番号
 
       call prcopn('DclGetTransNumber')
       call sgqtrn(DclGetTransNumber) 
       call prccls('DclGetTransNumber')
     end function
 !------------------------------------------------------------------------
-!ݥ饤ץߥƥ
+!ポリラインプリミティブ
 !---------------------------------
-    subroutine DclDrawLine1 (x,y,type,index)  !ޤ
+    subroutine DclDrawLine1 (x,y,type,index)  !折れ線を描く．
       real,      intent(in), dimension(:) :: x, y
       integer,   intent(in), optional     :: type, index
       integer                             :: type0, index0
@@ -165,7 +165,7 @@ module sgpack
     end subroutine
 
 !---------------------------------
-    subroutine DclDrawLine2 (x1,y1,x2,y2,type,index)  !ޤ
+    subroutine DclDrawLine2 (x1,y1,x2,y2,type,index)  !折れ線を描く．
       real,      intent(in)               :: x1, y1, x2, y2
       integer,   intent(in), optional     :: type, index
       integer                             :: type0, index0
@@ -281,39 +281,39 @@ module sgpack
         call sgocls('DclDrawLineProjected')
     end subroutine
 !---------------------------------
-    subroutine DclSetLineType(type)  !饤󥿥פꤹ롥   
-      integer, intent(in) :: type    !
+    subroutine DclSetLineType(type)  !ラインタイプを設定する．   
+      integer, intent(in) :: type    !線種
 
       call prcopn('DclSetLineType')
       call sgsplt(type)
       call prccls('DclSetLineType')
     end subroutine
 !---------------------------------
-    subroutine DclSetLineIndex(index)  !饤󥤥ǥꡥ   
-      integer,   intent(in) :: index    !饤󥤥ǥ 
+    subroutine DclSetLineIndex(index)  !ラインインデクスの設定．   
+      integer,   intent(in) :: index    !ラインインデクス 
 
       call prcopn('DclSetLineIndex')
       call sgspli(index)
       call prccls('DclSetLineIndex')
     end subroutine
 !---------------------------------
-    subroutine DclSetLineText(text)  !٥ʸꡥ  
-      character(len=*), intent(in) :: text  !ʸʽͤ'A')
+    subroutine DclSetLineText(text)  !ラベルの文字列設定．  
+      character(len=*), intent(in) :: text  !描く文字列（初期値は'A')
 
       call prcopn('DclSetLineText')
       call sgsplc(text)
       call prccls('DclSetLineText')
     end subroutine
 !---------------------------------
-    subroutine DclSetLineTextSize(height)  !٥ʸ  
-      real, intent(in) :: height  !ʸι⤵
+    subroutine DclSetLineTextSize(height)  !ラベルの文字高設定  
+      real, intent(in) :: height  !文字列の高さ
 
       call prcopn('DclSetLineTextSize')
       call sgspls(height)
       call prccls('DclSetLineTextSize')
     end subroutine
 !---------------------------------
-    subroutine DclNextLineText()  !٥κǸʸֹ䤹
+    subroutine DclNextLineText()  !ラベルの最後の文字番号を増やす．
 
       call prcopn('DclNextLineText')
       call sgnplc()
@@ -337,7 +337,7 @@ module sgpack
     end function
 !---------------------------------
     subroutine DclGetLineText(text)   
-      character(len=*), intent(out) :: text !ʸʽͤ'A')
+      character(len=*), intent(out) :: text !描く文字列（初期値は'A')
 
       call prcopn('DclGetLineText')
       call sgqplc(text) 
@@ -352,7 +352,7 @@ module sgpack
       call prccls('DclGetLineTextSize')
     end function
 !------------------------------------------------------------------------------
-! ݥޡץߥƥ
+! ポリマーカープリミティブ
 !---------------------------------
     subroutine DclDrawMarker(x,y,type,index,height)
       real,      intent(in), dimension(:) :: x, y
@@ -450,24 +450,24 @@ module sgpack
 
     end subroutine
 !---------------------------------
-    subroutine DclSetMarkerType(type)  !ޡפꡥ    
-      integer, intent(in) :: type    !ޡ
+    subroutine DclSetMarkerType(type)  !マーカータイプの設定．    
+      integer, intent(in) :: type    !マーカータイプ
 
       call prcopn('DclSetMarkerType')
       call sgspmt(type)
       call prccls('DclSetMarkerType')
     end subroutine
 !---------------------------------
-    subroutine DclSetMarkerIndex(index)  !ޡΥ饤󥤥ǥ  
-      integer,   intent(in) :: index     !饤󥤥ǥ 
+    subroutine DclSetMarkerIndex(index)  !マーカーのラインインデクスの設定  
+      integer,   intent(in) :: index     !ラインインデクス 
 
       call prcopn('DclSetMarkerIndex')
       call sgspmi(index)
       call prccls('DclSetMarkerIndex')
     end subroutine
 !---------------------------------
-    subroutine DclSetMarkerSize(height)   !ޡ礭ꡥ     
-      real,    intent(in) :: height    !ޡ礭
+    subroutine DclSetMarkerSize(height)   !マーカーの大きさ設定．     
+      real,    intent(in) :: height    !マーカーの大きさ
 
       call prcopn('DclSetMarkerSize')
       call sgspms(height) 
@@ -475,7 +475,7 @@ module sgpack
     end subroutine
 !---------------------------------
     function DclGetMarkerType()  
-      integer :: DclGetMarkerType     !ޡ
+      integer :: DclGetMarkerType     !マーカータイプ
 
       call prcopn('DclGetMarkerType')
       call sgqpmt(DclGetMarkerType) 
@@ -483,7 +483,7 @@ module sgpack
     end function
 !---------------------------------
     function DclGetMarkerIndex()
-      integer :: DclGetMarkerIndex     !饤󥤥ǥ 
+      integer :: DclGetMarkerIndex     !ラインインデクス 
 
       call prcopn('DclGetMarkerIndex')
       call sgqpmi(DclGetMarkerIndex)
@@ -491,19 +491,19 @@ module sgpack
     end function
 !---------------------------------
     function DclGetMarkerSize()
-      real :: DclGetMarkerSize     !ޡ礭
+      real :: DclGetMarkerSize     !マーカーの大きさ
 
       call prcopn('DclGetMarkerSize')
       call sgqpms(DclGetMarkerSize)
       call prccls('DclGetMarkerSize')
     end function
 !------------------------------------------------------------------
-!     ƥ
+!     テキスト
 !---------------------------------
     subroutine DclDrawText(x, y, text, height, angle, centering, index) 
-      real,             intent(in) :: x, y          !ʸΰ
-      character(len=*), intent(in) :: text          !ʸ
-      real,             intent(in) :: height, angle !ʸι⤵
+      real,             intent(in) :: x, y          !文字の位置
+      character(len=*), intent(in) :: text          !文字列
+      real,             intent(in) :: height, angle !文字の高さ
       integer,          intent(in) :: centering,index
 
       optional :: height, angle, centering,index
@@ -534,9 +534,9 @@ module sgpack
 !---------------------------------
     subroutine DclDrawTextNormalized(x, y, text, height, angle, centering, index)
 
-      real,             intent(in) :: x, y          !ʸΰ
-      character(len=*), intent(in) :: text          !ʸ
-      real,             intent(in) :: height, angle !ʸι⤵
+      real,             intent(in) :: x, y          !文字の位置
+      character(len=*), intent(in) :: text          !文字列
+      real,             intent(in) :: height, angle !文字の高さ
       integer,          intent(in) :: centering,index
 
       optional :: height, angle, centering,index
@@ -567,9 +567,9 @@ module sgpack
 !---------------------------------
     subroutine DclDrawTextProjected(x, y, text, height, angle, centering, index)
 
-      real,             intent(in) :: x, y          !ʸΰ
-      character(len=*), intent(in) :: text          !ʸ
-      real,             intent(in) :: height, angle !ʸι⤵
+      real,             intent(in) :: x, y          !文字の位置
+      character(len=*), intent(in) :: text          !文字列
+      real,             intent(in) :: height, angle !文字の高さ
       integer,          intent(in) :: centering,index
 
       optional :: height, angle, centering,index
@@ -598,32 +598,32 @@ module sgpack
         call sgocls('DclDrawTextProjected')
     end subroutine
 !---------------------------------
-    subroutine DclSetTextHeight(height)  !ʸι⤵ꡥ  
-      real,  intent(in) :: height  !ʸι⤵
+    subroutine DclSetTextHeight(height)  !文字の高さ設定．  
+      real,  intent(in) :: height  !文字の高さ
 
       call prcopn('DclSetTextHeight')
       call sgstxs(height)
       call prccls('DclSetTextHeight')
     end subroutine
 !---------------------------------
-    subroutine DclSetTextAngle(angle)  !ʸγ٤ꡥ  
-      real,  intent(in) :: angle   !ʸη٤ñ̤Ϳ 
+    subroutine DclSetTextAngle(angle)  !文字列の角度の設定．  
+      real,  intent(in) :: angle   !文字列の傾きを度の単位で与える 
 
       call prcopn('DclSetTextAngle')
       call sgstxr(nint(angle))
       call prccls('DclSetTextAngle')
     end subroutine
 !---------------------------------
-    subroutine DclSetTextIndex(index)  !ʸΥ饤󥤥ǥꡥ                 
-      integer,   intent(in) :: index     !饤󥤥ǥ 
+    subroutine DclSetTextIndex(index)  !文字列のラインインデクスの設定．                 
+      integer,   intent(in) :: index     !ラインインデクス 
 
       call prcopn('DclSetTextIndex')
       call sgstxi(index) 
       call prccls('DclSetTextIndex')
     end subroutine
 !---------------------------------
-    subroutine DclSetTextPosition(centering)  !ʸΥ󥿥󥰥ץ
-      integer,   intent(in) :: centering   !󥿥󥰥ץ
+    subroutine DclSetTextPosition(centering)  !文字列のセンタリングオプション設定
+      integer,   intent(in) :: centering   !センタリングオプション
 
       call prcopn('DclSetTextPosition')
       call sgstxc(centering)
@@ -631,7 +631,7 @@ module sgpack
     end subroutine
 !---------------------------------
     function DclGetTextHeight() 
-      real :: DclGetTextHeight  !ʸι⤵
+      real :: DclGetTextHeight  !文字の高さ
 
       call prcopn('DclGetTextHeight')
       call sgqtxs(DclGetTextHeight) 
@@ -639,7 +639,7 @@ module sgpack
     end function
 !---------------------------------
     function DclGetTextAngle()
-      real :: DclGetTextAngle      !ʸη٤ñ̤Ϳ
+      real :: DclGetTextAngle      !文字列の傾きを度の単位で与える
 
       call prcopn('DclGetTextAngle')
       call sgqtxr(irot)
@@ -648,7 +648,7 @@ module sgpack
     end function
 !---------------------------------
     function DclGetTextIndex() 
-      integer :: DclGetTextIndex      !饤󥤥ǥ
+      integer :: DclGetTextIndex      !ラインインデクス
 
       call prcopn('DclGetTextIndex')
       call sgqtxi(DclGetTextIndex) 
@@ -656,16 +656,16 @@ module sgpack
     end function
 !---------------------------------
     function DclGetTextPosition()  
-      integer :: DclGetTextPosition   !󥿥󥰥ץ
+      integer :: DclGetTextPosition   !センタリングオプション
 
       call prcopn('DclGetTextPosition')
       call sgqtxc(DclGetTextPosition)  
       call prccls('DclGetTextPosition')
     end function
 !-------------------------------------------------------------
-! ȡץߥƥ
+! トーンプリミティブ
 !---------------------------------
-    subroutine DclShadeRegion(x, y, pattern)  !u ɸϤ¿ѷΰɤĤ֤
+    subroutine DclShadeRegion(x, y, pattern)  !u 座標系で多角形領域の塗りつぶし．
       real,    intent(in), dimension(:) :: x,y 
       integer, intent(in), optional     :: pattern
 
@@ -722,23 +722,23 @@ module sgpack
         call sgocls('DclShadeRegionProjected')
     end subroutine
 !---------------------------------
-    subroutine DclSetShadePattern(pattern) ! ȡѥֹ
-      integer,   intent(in) :: pattern  !ȡѥֹ
+    subroutine DclSetShadePattern(pattern) ! トーンパターン番号設定
+      integer,   intent(in) :: pattern  !トーンパターン番号
 
       call prcopn('DclSetShadePattern')
       call sgstnp(pattern) 
       call prccls('DclSetShadePattern')
     end subroutine
 !---------------------------------
-    function DclGetShadePattern() !ꤵƤȡѥֹ滲
-      integer :: DclGetShadePattern     !ꤵƤȡѥֹ
+    function DclGetShadePattern() !現在設定されているトーンパターン番号参照
+      integer :: DclGetShadePattern     !現在設定されているトーンパターン番号
 
       call prcopn('DclGetShadePattern')
       call sgqtnp(DclGetShadePattern)
       call prccls('DclGetShadePattern')
     end function
 !-------------------------------------------------------------------------
-!     ֥ץߥƥ
+!     アローサブプリミティブ
 !-------------------------------------------------------------------------
     subroutine DclDrawArrow(x1,y1,x2,y2,type,index)
       real,    intent(in)           :: x1, y1, x2, y2
@@ -797,32 +797,32 @@ module sgpack
         call sgocls('DclDrawArrowProjected')
     end subroutine
 !---------------------------------
-    subroutine DclSetArrowLineType(type)  !ʬΥ饤󥿥פꤹ롥 
-      integer,   intent(in) :: type  !ʬΥ饤󥿥 
+    subroutine DclSetArrowLineType(type)  !描く線分のラインタイプを設定する． 
+      integer,   intent(in) :: type  !線分のラインタイプ 
 
       call prcopn('DclSetArrowLineType')
       call sgslat(type)
       call prccls('DclSetArrowLineType')
     end subroutine
 !---------------------------------
-    subroutine DclSetArrowLineIndex(index) !ʬ 饤󥤥ǥꤹ
-      integer,   intent(in) :: index  !ʬΥ饤󥤥ǥ 
+    subroutine DclSetArrowLineIndex(index) !描く線分の ラインインデクスを設定する
+      integer,   intent(in) :: index  !線分のラインインデクス 
 
       call prcopn('DclSetArrowLineIndex')
       call sgslai(index)
       call prccls('DclSetArrowLineIndex')
     end subroutine
 !---------------------------------
-    function DclGetArrowLineType() !ꤵƤ饤󥿥
-      integer :: DclGetArrowLineType   !ʬΥ饤󥿥
+    function DclGetArrowLineType() !現在設定されているラインタイプ
+      integer :: DclGetArrowLineType   !線分のラインタイプ
 
       call prcopn('DclGetArrowLineType')
       call sgqlat(DclGetArrowLineType)
       call prccls('DclGetArrowLineType')
     end function
 !---------------------------------
-    function DclGetArrowLineIndex() !ꤵƤ饤󥤥ǥ
-      integer :: DclGetArrowLineIndex      !ʬΥ饤󥤥ǥ 
+    function DclGetArrowLineIndex() !現在設定されているラインインデクス
+      integer :: DclGetArrowLineIndex      !線分のラインインデクス 
 
       call prcopn('DclGetArrowLineIndex')
       call sgqlai(DclGetArrowLineIndex) 
