@@ -40,13 +40,13 @@
       LOGICAL CONTINU_FLAG(NX,NY)  ! FLAG VALUE TO PREVENT THE IDENTICAL 
                                    ! STREAM LINE FROM CONTINUOUS COUNTING
                                    ! IN EACH GRID.
-                                   ! ƥåפƱʻˤΤ
-                                   ! Ȥ뤳ȤɤΥե饰.
-      LOGICAL PFX, PFY             ! Ƚ̤.
-                                   ! ξ, λϤޤȽ
-                                   ! ǿפƤʤФʤʤ.
-                                   ! Ĥޤ, X ˶ʤ,
-                                   ! I=1, NX Ʊ٥ȥ뤬äƤɬ.
+                                   ! 次ステップで同じ格子点にいるのを
+                                   ! カウントすることを防ぐためのフラグ.
+      LOGICAL PFX, PFY             ! 周期境界かを判別する.
+                                   ! 周期境界の場合, 配列の始まりと終わりの
+                                   ! 要素数が一致していなければならない.
+                                   ! つまり, X 方向に境界条件なら,
+                                   ! I=1, NX は同じベクトルが入っている必要.
       LOGICAL DTV                  ! FLAG OF VARYING DT (AUTOMATIC).
 
 *-- FUNCTION
@@ -85,30 +85,30 @@
 
 *-- CHECKING WHERE A STREAM LINE PASS GRIDS.
 *-- WHEN COUNTING NUMBER EXCEEDS "THRES", STOPPING TO CALCULATE A STREAM LINE.
-*-- ʲ, ׻ǽγʻ򥫥.
+*-- 以下で, 計算最初の格子点をカウント.
       M=IBLKGE( X, NX, INI_X )
       N=IBLKGE( Y, NY, INI_Y )
       INI_M=M
       INI_N=N
-      IF(M.EQ.NX)THEN  !* ν NX+1, NY+1 (ΰ賰) 򻲾Ȥʤν.
+      IF(M.EQ.NX)THEN  !* 下の処理で NX+1, NY+1 (領域外) を参照しないための処理.
          M=NX-1
       END IF
       IF(N.EQ.NY)THEN
          N=NY-1
       END IF
-      IF((INI_X-X(M)).GE.(X(M+1)-INI_X))THEN  ! M+1 ̲
-         IF((INI_Y-Y(N)).GE.(Y(N+1)-INI_Y))THEN  ! N+1 ̲
+      IF((INI_X-X(M)).GE.(X(M+1)-INI_X))THEN  ! M+1 の点を通過
+         IF((INI_Y-Y(N)).GE.(Y(N+1)-INI_Y))THEN  ! N+1 の点を通過
             GRID_FLAG(M+1,N+1)=GRID_FLAG(M+1,N+1)+1
             CONTINU_FLAG(M+1,N+1)=.TRUE.
-         ELSE  ! N ̲
+         ELSE  ! N の点を通過
             GRID_FLAG(M+1,N)=GRID_FLAG(M+1,N)+1
             CONTINU_FLAG(M+1,N)=.TRUE.
          END IF
-      ELSE  ! M ̲
-         IF((INI_Y-Y(N)).GE.(Y(N+1)-INI_Y))THEN  ! N+1 ̲
+      ELSE  ! M の点を通過
+         IF((INI_Y-Y(N)).GE.(Y(N+1)-INI_Y))THEN  ! N+1 の点を通過
             GRID_FLAG(M,N+1)=GRID_FLAG(M,N+1)+1
             CONTINU_FLAG(M,N+1)=.TRUE.
-         ELSE  ! N ̲
+         ELSE  ! N の点を通過
             GRID_FLAG(M,N)=GRID_FLAG(M,N)+1
             CONTINU_FLAG(M,N)=.TRUE.
          END IF
@@ -127,13 +127,13 @@
 
          DO 99 ID=1,4  !* RK4 scheme start
 *-- RESEARCHING THE NEAREST GRID POINTS FOR INTERPOLATING
-*-- Ѥζ˵ʻõ
+*-- 内挿用の近傍格子点探索
 
             M=IBLKGE( X, NX, INTER_P(1) )
             N=IBLKGE( Y, NY, INTER_P(2) )
-*-- ʲνԹ, ΰ趭ˤ 1 ʻ¦ؤ餹.
-*-- ޻ˤϾ򻲾ȤƷ׻Τ, ν򤷤Ƥ
-*-- ܼŪˤϱƶʤ.
+*-- 以下の処理の都合上, 領域境界上にある場合は 1 格子内側へずらす.
+*-- 内挿時には小さい方を参照点として計算するので, この処理をしても
+*-- 本質的には影響しない.
             IF(INTER_P(1).EQ.X(NX))THEN
                M=NX-1
             END IF
@@ -145,13 +145,13 @@
 *-- A GRID POINT UNDEFINED FOR VECTOR VALUE,
 *-- STOPPING TO CALCULATE THE STREAM LINE.
 *-- AND, STANDARD OUTPUTTING ITS CONTENT.
-*-- ®پ줬 UNDEF Ǥ, λǤʹߤΥǡˤ UNDEF 
-*-- , UNDEF ƶϰ̲ᤷݤ.
-*-- ޤ, INTERPO_SEARCH ˤƸΰ賰ξ⤽ʹ߷׻Բǽ
-*-- Ǥݤ.
-*-- ν RUNGE-KUTTA Ƿ׻ 4 η׻ˤ
-*-- Ԥ.
-*-- 椨, ʲ IF ʬ 4 ФƤ.
+*-- 速度場が UNDEF であれば, その時点でそれ以降のデータには UNDEF を
+*-- 代入し, UNDEF 影響範囲内を通過した旨を伝える.
+*-- また, INTERPO_SEARCH において検索点が領域外の場合もそれ以降計算不可能
+*-- である旨を通知.
+*-- この処理は RUNGE-KUTTA で計算する 4 回の傾き計算において
+*-- 毎回行われる.
+*-- ゆえに, 以下の IF 分は 4 回出てくる.
             IF(M.EQ.0.OR.M.EQ.NX)THEN
                IF(PFX.EQV..TRUE.)THEN
                   IF(M.EQ.0)THEN
@@ -216,49 +216,49 @@
             END IF
 
 *-- CALCULATING THE EACH TENDENCY (K,L)
-*-- 4 ηФ (RK4) Τ, 4 󷫤֤.
-*-- , λˤ INTER_P 󹹿Ƥ, ιȼ
-*-- ȤΥ٥ȥ INTER_V ⹹Ƥ.
+*-- 4 点の傾向を出す (RK4) ので, 4 回繰り返す.
+*-- ただし, その時には INTER_P が毎回更新されており, この更新に伴い
+*-- 傾向を求めるときのベクトル INTER_V も更新されている.
             IF(ID.EQ.1)THEN
                K1=DT*INTER_V(1)
                L1=DT*INTER_V(2)
-*-- Ūήΰ֤׻
+*-- 一時的な流跡線の位置を計算
                X1=TRAJX(I)+0.5*K1
                Y1=TRAJY(I)+0.5*L1
                INTER_P=(/X1, Y1/)
             ELSE IF(ID.EQ.2)THEN
                K2=DT*INTER_V(1)
                L2=DT*INTER_V(2)
-*-- Ūήΰ֤׻
+*-- 一時的な流跡線の位置を計算
                X1=TRAJX(I)+0.5*K2
                Y1=TRAJY(I)+0.5*L2
                INTER_P=(/X1, Y1/)
             ELSE IF(ID.EQ.3)THEN
                K3=DT*INTER_V(1)
                L3=DT*INTER_V(2)
-*-- Ūήΰ֤׻
+*-- 一時的な流跡線の位置を計算
                X1=TRAJX(I)+K3
                Y1=TRAJY(I)+L3
                INTER_P=(/X1, Y1/)
             ELSE IF(ID.EQ.4)THEN
                K4=DT*INTER_V(1)
                L4=DT*INTER_V(2)
-*-- Ūήΰ֤׻
+*-- 一時的な流跡線の位置を計算
                X1=TRAJX(I)+K4
                Y1=TRAJY(I)+L4
-*               INTER_P=(/X1, Y1/)  !* ޷׻˻ȤʤΤǵʤ.
+*               INTER_P=(/X1, Y1/)  !* ここは内挿計算に使わないので求めない.
             END IF
 
-*-- ޤǤ 1 
+*-- ここまでで 1 サイクル
  99      CONTINUE
 
          X1=TRAJX(I)+(1.0/6.0)*(K1+2.0*K2+2.0*K3+K4)
          Y1=TRAJY(I)+(1.0/6.0)*(L1+2.0*L2+2.0*L3+L4)
 
 *-- CHECKING THAT THERE IS A CALCULATING STREAM LINE IN THE DRAWING REGION.
-*-- ׻ TRAJ ΰ¸ߤƤ뤫ǧ
+*-- 計算した TRAJ が領域内に存在しているか確認
          IF(X1.LT.X(1).OR.X1.GT.X(NX))THEN
-            IF(PFX.EQV..TRUE.)THEN  !* ξ, ήΰ֤Ѳ 1 ή֤ undef .
+            IF(PFX.EQV..TRUE.)THEN  !* 周期境界の場合, 流線の位置を変化させ 1 つ前の流線位置に undef を代入する.
                IF(X1.LT.X(1))THEN
                   X1=X(NX)+(X1-X(1))
                ELSE
@@ -307,17 +307,17 @@
 
 *-- CHECKING WHERE A STREAM LINE PASS GRIDS.
 *-- WHEN COUNTING NUMBER EXCEEDS "THRES", STOPPING TO CALCULATE A STREAM LINE.
-*-- ʲ, ɤγʻ̲ᤷ򥫥Ȥ.
-*-- ޤ, ̲ THRES ۤƤ, GOTO 101 ǽλ.
-         IF((X1-X(M)).GE.(X(M+1)-X1))THEN  ! M+1 ̲
-            IF((Y1-Y(N)).GE.(Y(N+1)-Y1))THEN  ! N+1 ̲
+*-- 以下で, どの格子点を通過したかをカウントする.
+*-- また, 通過数が THRES を越えていると, GOTO 101 で終了.
+         IF((X1-X(M)).GE.(X(M+1)-X1))THEN  ! M+1 の点を通過
+            IF((Y1-Y(N)).GE.(Y(N+1)-Y1))THEN  ! N+1 の点を通過
                IF(CONTINU_FLAG(M+1,N+1).EQV..FALSE.)THEN
                   GRID_FLAG(M+1,N+1)=GRID_FLAG(M+1,N+1)+1
                   CONTINU_FLAG=.FALSE.
                   CONTINU_FLAG(M+1,N+1)=.TRUE.
                   SGRID=1
                   IF(GRID_FLAG(M+1,N+1).GT.THRES)THEN
-                     IF(M+1.NE.INI_M.OR.N+1.NE.INI_N)THEN  ! äƤν (äƤʤȤ IF ʸ)
+                     IF(M+1.NE.INI_M.OR.N+1.NE.INI_N)THEN  ! 初期点に戻ってくる場合の処理 (戻ってこないとこの IF 文に入る)
                         TRAJN=I
                         GOTO 101
                      ELSE
@@ -330,14 +330,14 @@
                ELSE  ! COUNTING THE EXISTING OF THE SAME GRID
                   SGRID=SGRID+1
                END IF
-            ELSE  ! N ̲
+            ELSE  ! N の点を通過
                IF(CONTINU_FLAG(M+1,N).EQV..FALSE.)THEN
                   GRID_FLAG(M+1,N)=GRID_FLAG(M+1,N)+1
                   CONTINU_FLAG=.FALSE.
                   CONTINU_FLAG(M+1,N)=.TRUE.
                   SGRID=1
                   IF(GRID_FLAG(M+1,N).GT.THRES)THEN
-                     IF(M+1.NE.INI_M.OR.N.NE.INI_N)THEN  ! äƤν (äƤʤȤ IF ʸ)
+                     IF(M+1.NE.INI_M.OR.N.NE.INI_N)THEN  ! 初期点に戻ってくる場合の処理 (戻ってこないとこの IF 文に入る)
                         TRAJN=I
                         GOTO 101
                      ELSE
@@ -351,15 +351,15 @@
                   SGRID=SGRID+1
                END IF
             END IF
-         ELSE  ! M ̲
-            IF((Y1-Y(N)).GE.(Y(N+1)-Y1))THEN  ! N+1 ̲
+         ELSE  ! M の点を通過
+            IF((Y1-Y(N)).GE.(Y(N+1)-Y1))THEN  ! N+1 の点を通過
                IF(CONTINU_FLAG(M,N+1).EQV..FALSE.)THEN
                   GRID_FLAG(M,N+1)=GRID_FLAG(M,N+1)+1
                   CONTINU_FLAG=.FALSE.
                   CONTINU_FLAG(M,N+1)=.TRUE.
                   SGRID=1
                   IF(GRID_FLAG(M,N+1).GT.THRES)THEN
-                     IF(M.NE.INI_M.OR.N+1.NE.INI_N)THEN  ! äƤν (äƤʤȤ IF ʸ)
+                     IF(M.NE.INI_M.OR.N+1.NE.INI_N)THEN  ! 初期点に戻ってくる場合の処理 (戻ってこないとこの IF 文に入る)
                         TRAJN=I
                         GOTO 101
                      ELSE
@@ -372,14 +372,14 @@
                ELSE  ! COUNTING THE EXISTING OF THE SAME GRID
                   SGRID=SGRID+1
                END IF
-            ELSE  ! N ̲
+            ELSE  ! N の点を通過
                IF(CONTINU_FLAG(M,N).EQV..FALSE.)THEN
                   GRID_FLAG(M,N)=GRID_FLAG(M,N)+1
                   CONTINU_FLAG=.FALSE.
                   CONTINU_FLAG(M,N)=.TRUE.
                   SGRID=1
                   IF(GRID_FLAG(M,N).GT.THRES)THEN
-                     IF(M.NE.INI_M.OR.N.NE.INI_N)THEN  ! äƤν (äƤʤȤ IF ʸ)
+                     IF(M.NE.INI_M.OR.N.NE.INI_N)THEN  ! 初期点に戻ってくる場合の処理 (戻ってこないとこの IF 文に入る)
                         TRAJN=I
                         GOTO 101
                      ELSE
@@ -399,7 +399,7 @@
          TRAJY(I+1)=Y1
          TRAJN=I+1
 
-*-- ®پ줬ʳ Runge-Kutta ׻夿ޤޥˤʤ뤳Ȥ.
+*-- 速度場がゼロ以外で Runge-Kutta 計算上たまたまゼロになることがある.
          IF(TRAJX(I).EQ.TRAJX(I+1).AND.TRAJY(I).EQ.TRAJY(I+1))THEN
             GO TO 101
          ELSE IF(ABS(TRAJX(I+1)-TRAJX(I)).LT.(X(M+1)-X(M))/REAL(GLIM)
@@ -434,13 +434,13 @@ C      WRITE(*,*) "V CHECK", TRAJX(I:I+1), TRAJY(I:I+1), I
       REAL VALX(2)
       REAL V
     
-      ! Y(1) Ǥ X Ǥ
+      ! Y(1) での X 方向の内挿点での値
       VALX(1)=Z(1,1)+(P(1)-X(1))*(Z(2,1)-Z(1,1))/(X(2)-X(1))
     
-      ! Y(2) Ǥ X Ǥ
+      ! Y(2) での X 方向の内挿点での値
       VALX(2)=Z(1,2)+(P(1)-X(1))*(Z(2,2)-Z(1,2))/(X(2)-X(1))
     
-      ! X  Y Ǥ(줬)
+      ! X の内挿点からの Y 方向の内挿点での値(これが求める内挿点)
       V=VALX(1)+(P(2)-Y(1))*(VALX(2)-VALX(1))/(Y(2)-Y(1))
     
       ITRP2D=V
