@@ -132,8 +132,8 @@
  80            CONTINUE
 
 *-- IF NO_SHORT IS TRUE, NO DRAWING STREAM LINE WHOSE ARROW NUMBER IS ZERO
-*-- ήλȽˤ, ĤήȤߤʤ.
-*-- 𱩤Ͻ.
+*-- 流線の始点と終点が近似点にいれば, 閉じた流線とみなして描く.
+*-- 矢羽は終点に描く.
                IF(ARRCNT.EQ.0)THEN
                   IF(NO_SHORT.EQV..TRUE.)THEN
                      IF((TOTNM(I,K)-TOTSNM(I,K)+1).LE.2)THEN
@@ -144,12 +144,12 @@
                         IF(ABS(N-M).GT.1)THEN
                            GO TO 81
                         ELSE
-*-- ƤΤ, ûʤΤΥå
-*--  , , νƤа.
+*-- 一周しているのか, 短いだけなのかのチェック
+*--  始点, 終点, 終点１つ前の順に増減していれば一周.
                            CIRC_FLAG=
      &                        (TRX(TOTNM(I,K),K)-TRX(TOTNM(I,K)-1,K))
      &                        *(TRX(TOTSNM(I,K),K)-TRX(TOTNM(I,K),K))
-                           IF(CIRC_FLAG.LT.0.0)THEN  ! ñû
+                           IF(CIRC_FLAG.LT.0.0)THEN  ! 単に短いだけ
                               GO TO 81
                            ELSE
                               N=IBLKGE( T, NY, TRY(TOTSNM(I,K),K) )
